Skip to contents

A bare flagged / n headline is misleading when many rows are unchecked or only "possible", so this reports the full breakdown and two rates: per total, and per successfully-checked.

Usage

exposure_score(x)

Arguments

x

A retraction_result.

Value

A named list: n_total, n_checked, n_flagged, n_possible, n_unchecked, flagged_per_total, flagged_per_checked.

Examples

# \donttest{
res <- check_dois("10.1016/S0140-6736(97)11096-0")
exposure_score(res)
#> $n_total
#> [1] 1
#> 
#> $n_checked
#> [1] 1
#> 
#> $n_flagged
#> [1] 1
#> 
#> $n_possible
#> [1] 0
#> 
#> $n_unchecked
#> [1] 0
#> 
#> $flagged_per_total
#> [1] 1
#> 
#> $flagged_per_checked
#> [1] 1
#> 
# }