Skip to contents

Opens a small web app to upload a bibliography or document and browse the flagged, possible, and clean references interactively.

Usage

retraction_app(...)

Arguments

...

Passed to shiny::runApp().

Value

Runs the app; does not return a value. Requires the suggested shiny and DT packages.

Examples

if (FALSE) { # \dontrun{
retraction_app()
} # }